#[non_exhaustive]pub struct Config { /* private fields */ }Expand description
Controller-wide (engine) configuration.
These settings drive the shared module clock and therefore apply to the whole controller, not an individual slot.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn with_clock_source(self, clock_source: ClockSource) -> Self
pub fn with_clock_source(self, clock_source: ClockSource) -> Self
Assign the given value to the clock_source field.
Sourcepub fn clock_source(&self) -> ClockSource
pub fn clock_source(&self) -> ClockSource
The clock source for the module clock.
Sourcepub fn with_module_div(self, module_div: u8) -> Self
pub fn with_module_div(self, module_div: u8) -> Self
Assign the given value to the module_div field.
Sourcepub fn module_div(&self) -> u8
pub fn module_div(&self) -> u8
The module-clock divider (valid range 2..=16).